/****************************************************************************

 This file is part of GLC-Player.
 Copyright (C) 2007-2008 Laurent Ribon (laumaya@users.sourceforge.net)
 Version 1.6.0, packaged on August 2008.

 http://www.glc-player.net

 GLC-Player is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLC-Player is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLC-Player; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

*****************************************************************************/

#ifndef SESSIONFILE_H_
#define SESSIONFILE_H_

#include "FileEntry.h"
#include <QFile>
#include <QList>
#include <QString>
#include <QXmlStreamWriter>
#include <QXmlStreamReader>

//////////////////////////////////////////////////////////////////////
//! \class Sessionfile
/*! \brief SessionFile : The session file reader and loader*/
//////////////////////////////////////////////////////////////////////
class AlbumFile
{
//////////////////////////////////////////////////////////////////////
/*! @name Constructor / Destructor */
//@{
//////////////////////////////////////////////////////////////////////	

public:
	//! Default constructor
	AlbumFile();
	//! Default destructor
	virtual ~AlbumFile();
//@}
/////////////////////////////////////////////////////////////////////
// Public Interface
//////////////////////////////////////////////////////////////////////
public:
	//! Load a session file
	/* Return the file entry list as result
	 */
	QList<FileEntry> loadAlbumFile(QFile*);
	
	//! Save a session file
	/*
	 * The file must exist and be in write mode
	 */
	void saveAlbumFile(const QList<FileEntry>&, QFile*);

//////////////////////////////////////////////////////////////////////
// Private services Functions
//////////////////////////////////////////////////////////////////////
private:
	//! Write the header of xml document
	void writeHeader() const;
	//! Write a model in the current xml document
	void writeModel(const FileEntry&);
	//! Check if the session file is valid
	/*!
	 * Throw GLC_FileFormatException if the session file is not valid
	 */
	bool checkAlbumFileValidity();
	//! Convert current model xml element to a FileEntry object
	FileEntry currentModelToFileEnty();

//////////////////////////////////////////////////////////////////////
// private member
//////////////////////////////////////////////////////////////////////
private:	
	QXmlStreamWriter* m_pStreamWriter;
	QXmlStreamReader* m_pStreamReader;
	QDir m_SessionPathDir;
};

#endif /*SESSIONFILE_H_*/
