/****************************************************************************

 This file is part of GLC-Player.
 Copyright (C) 2007-2008 Laurent Ribon (laumaya@users.sourceforge.net)
 Version 1.6.0, packaged on August 2008.

 http://www.glc-player.net

 GLC-Player is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLC-Player is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLC-Player; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

*****************************************************************************/

#include "FileEntry.h"
#include <GLC_Mesh2>

// Default constructor
FileEntry::FileEntry(const QString& fileName)
: m_FileName(fileName)
, m_IsLoading(false)
, m_IsLoaded(false)
, m_World()
, m_Error()
, m_Camera()
, m_CameraIsSet(false)
, m_PolyMode(GL_FILL)
, m_NumberOfFaces(0)
, m_NumberOfVertex(0)
, m_AngleOfView(35.0) // default angle is 35 degre
{
	
}

// Construct from fileName and camera
FileEntry::FileEntry(const QString& fileName, const GLC_Camera& cam, const double& angle)
: m_FileName(fileName)
, m_IsLoading(false)
, m_IsLoaded(false)
, m_World()
, m_Error()
, m_Camera(cam)
, m_CameraIsSet(true)
, m_PolyMode(GL_FILL)
, m_AngleOfView(angle)
{
	
}

// Copy constructor
FileEntry::FileEntry(const FileEntry& entry)
: m_FileName(entry.m_FileName)
, m_IsLoading(entry.m_IsLoading)
, m_IsLoaded(entry.m_IsLoaded)
, m_World(entry.m_World)
, m_Error(entry.m_Error)
, m_Camera(entry.m_Camera)
, m_CameraIsSet(entry.m_CameraIsSet)
, m_AngleOfView(entry.m_AngleOfView)
{
	
}
// the destructor
FileEntry::~FileEntry()
{
	
}

//////////////////////////////////////////////////////////////////////
// Public Interface
//////////////////////////////////////////////////////////////////////

// Set the GLC_World of this file entry
void FileEntry::setWorld(GLC_World& world)
{
	m_IsLoaded= true;
	m_World= world;
	m_NumberOfFaces= m_World.getNumberOfFaces();
	m_NumberOfVertex= m_World.getNumberOfVertex();
}

// return true if this entry is ready to load
bool FileEntry::isReadyToLoad() const
{
	return (!m_IsLoading) && (!m_IsLoaded) && (!errorOccurWhileLoading());
}

