/****************************************************************************

 This file is part of GLC-Player.
 Copyright (C) 2007-2008 Laurent Ribon (laumaya@users.sourceforge.net)
 Version 1.6.0, packaged on August 2008.

 http://www.glc-player.net

 GLC-Player is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLC-Player is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLC-Player; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

*****************************************************************************/

#include "OpenFileThread.h"
#include <GLC_FileFormatException>


OpenFileThread::OpenFileThread(GLC_Factory *pFactory)
: m_pFactory(pFactory)
, m_pLoadingFile(NULL)
, m_pWorld(NULL)
, m_ErrorMsg()
{
	connect(m_pFactory, SIGNAL(currentQuantum(int)), this, SIGNAL(currentQuantum(int)));
}

OpenFileThread::~OpenFileThread()
{
	if (NULL != m_pWorld)
	{
		delete m_pWorld;
	}
	if (NULL != m_pLoadingFile)
	{
		delete m_pLoadingFile;
	}		
}

GLC_World OpenFileThread::getWorld()
{
	GLC_World result;
	if (NULL != m_pWorld)
	{
		result= (*m_pWorld);
		delete m_pWorld;
		m_pWorld= NULL;
	}
	return result;
}

QString OpenFileThread::getFileName() const
{
	if (NULL != m_pLoadingFile)
	{
		return m_pLoadingFile->fileName();
	}
	else
	{
		return QString(tr("Untiteled"));
	}
}

void OpenFileThread::setOpenFile(QFile *openFile)
{
	m_pLoadingFile= new QFile(openFile->fileName());
		
}
void OpenFileThread::run()
{
	try
	{
		m_pWorld= m_pFactory->createWorld(*m_pLoadingFile);
		m_ErrorMsg= "";
	}
	catch (std::exception &e)
	{
		if (NULL != m_pWorld)
		{
			delete m_pWorld;
			m_pWorld= NULL;
		}
		m_pLoadingFile->close();
		m_ErrorMsg= e.what();
		emit loadError();
	}
}

