/****************************************************************************

 This file is part of GLC-Player.
 Copyright (C) 2007-2008 Laurent Ribon (laumaya@users.sourceforge.net)
 Version 1.6.0, packaged on August 2008.

 http://www.glc-player.net

 GLC-Player is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLC-Player is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLC-Player; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

 *****************************************************************************/

#include "SelectionProperty.h"
#include <GLC_Instance>
#include <GLC_Mesh2>

SelectionProperty::SelectionProperty(QWidget *parent)
: QWidget(parent)
, m_pSelection(NULL)
{
	setupUi(this);
	connect(reverseNormalsCmd, SIGNAL(clicked()), this, SLOT(reverseNormals()));
	connect(hideShowCmd, SIGNAL(clicked()), this, SIGNAL(showOrHide()));
}

SelectionProperty::~SelectionProperty()
{
}

// Set the current selection
void SelectionProperty::setSelection(GLC_Instance* pSelection)
{
	m_pSelection= dynamic_cast<GLC_Mesh2*>(pSelection->getGeometry());
	Q_ASSERT(NULL != m_pSelection);
	
	selectionName->setText(m_pSelection->getName());
	numberOfVertex->setText(QString::number(m_pSelection->getNumberOfVertex()));
	numberOfFace->setText(QString::number(m_pSelection->getNumberOfFaces()));
	numberOfSubMaterial->setText(QString::number(m_pSelection->getNumberOfSubMaterial()));
	reverseNormalsCmd->setEnabled(true);
	hideShowCmd->setEnabled(true);
}
// Unset the current selection
void SelectionProperty::unsetSelection()
{
	m_pSelection= NULL;
	selectionName->clear();
	numberOfVertex->clear();
	numberOfFace->clear();
	numberOfSubMaterial->clear();
	reverseNormalsCmd->setEnabled(false);
	hideShowCmd->setEnabled(false);
}
// Reverse selection normals
void SelectionProperty::reverseNormals()
{
	if (NULL != m_pSelection)
	{
		m_pSelection->reverseNormal();
		emit updateView();
	}
}


