/****************************************************************************

 This file is part of GLC-Player.
 Copyright (C) 2007-2008 Laurent Ribon (laumaya@users.sourceforge.net)
 Version 1.6.0, packaged on August 2008.

 http://www.glc-player.net

 GLC-Player is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLC-Player is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLC-Player; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

*****************************************************************************/

#include "SettingsDialog.h"
#include <QSettings>
#include <QtGui>

SettingsDialog::SettingsDialog(const bool display, const QSize& size, const bool displayInfo, const bool quitConfirmation, QWidget *parent)
: QDialog(parent)
, m_InitLanguage()
, m_NewLanguage()
, m_ThumbnailSize(size)
{
	setupUi(this);
	
	// Init Display thumbnail check box
	if (display)
		displayThumbnail->setCheckState(Qt::Checked);
	else
		displayThumbnail->setCheckState(Qt::Unchecked);
		
	// Initialize Thumbnail size combo box
	QString sizeArray[6]= {"32x32", "40x40", "50x50", "60x60", "70x70", "80x80"};
	ThumbnailSize_Combo->addItem(sizeArray[0]);
	ThumbnailSize_Combo->addItem(sizeArray[1]);
	ThumbnailSize_Combo->addItem(sizeArray[2]);
	ThumbnailSize_Combo->addItem(sizeArray[3]);
	ThumbnailSize_Combo->addItem(sizeArray[4]);
	ThumbnailSize_Combo->addItem(sizeArray[5]);
	
	const QString stringSize(QString::number(m_ThumbnailSize.width()) + QString("x") + QString::number(m_ThumbnailSize.height()));
	int pos= 0;
	while (sizeArray[pos] != stringSize) pos++;
	ThumbnailSize_Combo->setCurrentIndex(pos);	
	ThumbnailSize_Combo->setEnabled(display);
	
	QSettings settings;
	m_InitLanguage= settings.value("currentLanguage").toString();
	languageComboBox->addItem(tr("English"));
	languageComboBox->addItem(tr("French"));
	
	if (m_InitLanguage == "fr")
	{
		languageComboBox->setCurrentIndex(1);
	}
	else
	{
		languageComboBox->setCurrentIndex(0);
	}

	// Init Display thumbnail check box
	if (displayInfo)
		displayViewInfoPanel->setCheckState(Qt::Checked);
	else
		displayViewInfoPanel->setCheckState(Qt::Unchecked);

	// Init Quit confirmation check box
	if (quitConfirmation)
		quitConfirmationActive->setCheckState(Qt::Checked);
	else
		quitConfirmationActive->setCheckState(Qt::Unchecked);

	// Signal and slot connection
	connect(languageComboBox, SIGNAL(currentIndexChanged(int)), this , SLOT(currentLanguageChange(int)));
	connect(displayThumbnail, SIGNAL(stateChanged(int)), this , SLOT(displayThumbnailStateChanged(int)));
	connect(ThumbnailSize_Combo, SIGNAL(currentIndexChanged(int)), this , SLOT(iconSizeChange(int)));
}

SettingsDialog::~SettingsDialog()
{
}

// Accept modifications
void SettingsDialog::accept()
{
	if (!m_NewLanguage.isEmpty() && (m_NewLanguage != m_InitLanguage))
	{
		QSettings settings;
		settings.setValue("currentLanguage", m_NewLanguage);
		QMessageBox::warning(this, tr("Warning"), tr("Restart Application to take setting into account."), QMessageBox::Ok);
		
	}
	
	QDialog::accept();
}
// Return true if thumbnail have to be shown
bool SettingsDialog::thumbnailHaveToBeDisplay() const
{
	return displayThumbnail->checkState() == Qt::Checked;
}

// get the thumbnail size
QSize SettingsDialog::getThumbnailSize() const
{
	return m_ThumbnailSize;
}

// return true if info have to be shown
bool SettingsDialog::infoHaveToBeShown() const
{
	return displayViewInfoPanel->checkState() == Qt::Checked;
}

//! return true if quit confirmation is needed
bool SettingsDialog::quitConfirmation() const
{
	return quitConfirmationActive->checkState() == Qt::Checked;
}

// The user change the current language
void SettingsDialog::currentLanguageChange(int index)
{
	switch (index)
	{
		case 0:
			m_NewLanguage= "en";
			break;
		case 1:
			m_NewLanguage= "fr";
			break;
		default:
			break;
	}
}
// The user change the state of display thumbnail
void SettingsDialog::displayThumbnailStateChanged(int state)
{
	const bool unableState= (state == Qt::Checked);
	ThumbnailSize_Combo->setEnabled(unableState);
}
// The user Change the icon size
void SettingsDialog::SettingsDialog::iconSizeChange(int index)
{
	switch (index)
	{
		case 0:
			m_ThumbnailSize= QSize(32, 32);
			break;
		case 1:
			m_ThumbnailSize= QSize(40, 40);
			break;
		case 2:
			m_ThumbnailSize= QSize(50, 50);
			break;
		case 3:
			m_ThumbnailSize= QSize(60, 60);
			break;
		case 4:
			m_ThumbnailSize= QSize(70, 70);
			break;				
		case 5:
			m_ThumbnailSize= QSize(80, 80);
			break;
		default:
			break;			
	}
}
