/****************************************************************************

 This file is part of GLC-Player.
 Copyright (C) 2007-2008 Laurent Ribon (laumaya@users.sourceforge.net)
 Version 1.6.0, packaged on August 2008.

 http://www.glc-player.net

 GLC-Player is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLC-Player is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLC-Player; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

*****************************************************************************/

#ifndef GLC_PLAYER_H
#define GLC_PLAYER_H

#include <QtGui/QMainWindow>
#include <glc_enum.h>
#include "ui_glc_player.h"
#include "OpenglView.h"
#include "OpenFileThread.h"
#include "FileEntry.h"

class SelectionProperty;
class EditLightDialog;

class glc_player : public QMainWindow
{
    Q_OBJECT

public:
    glc_player(QWidget *parent = 0);
    ~glc_player();
//////////////////////////////////////////////////////////////////////
// Virtual protected function
//////////////////////////////////////////////////////////////////////
protected:
	//! Close event handler
	void closeEvent(QCloseEvent*);

public:	
//////////////////////////////////////////////////////////////////////
// public Methods
//////////////////////////////////////////////////////////////////////
	void openOnEvent(QString);
	
//////////////////////////////////////////////////////////////////////
// public Slots
//////////////////////////////////////////////////////////////////////
public slots:
	//! an instance as been selected
	void select(GLC_Instance*);
	//! an instance as been unselected
	void unselect();
	//! Info panel not supported
	void hideInfoPanel();
//////////////////////////////////////////////////////////////////////
// private Slots
//////////////////////////////////////////////////////////////////////
private slots:
	//! Set Instance visibility
	void showOrHide();
	//! Hide unseleted instance
	void hideUnselected();
	//! Show All instance
	void showAll();
	//! Swap visible space
	void swapVisibleSpace();
	//! update the value of the progress bar
	void updateProgressBar(int);
	//! Remove all file item from the current album
	bool newAlbum(bool confirmation= true);
	//! Menu File
	//! Open An existing file
	void open();
	//! Open An existing album
	void openAlbum();
	//! Save the current album
	void saveAlbum();
	//! Save As a new album
	void saveAlbumAs();
	//! Open a Recent File
	void openRecentFile();
	//! Open a Recent Album
	void openRecentAlbum();
	//! Menu Window
	//! Menu Edit
	//! View and edit mesh property
	void meshProperty();
	//! Menu View
	//! Reframe the view
	void reframe();
	//! Select mode
	void selectMode();
	//! define view center mode
	void viewCenterMode();
	//! Pan the view mode
	void panMode();
	//! Rotate the view mode
	void rotateMode();
	//! Zoom the view mode
	void zoomMode();
	//! Menu Tools
	//! Show application settings dialog
	void showSettings();
	//! A file as been Opened
	void fileOpened();
	//! load of File failed
	void loadFileFailed();
	//! Current file Item Changed
	void currentFileItemChanged(QListWidgetItem *, QListWidgetItem *);
	//! File Item as been clicked
	void fileItemClicked(QListWidgetItem *);
	//! Remove unload item
	void removeUnloadFileItem();
	//! Remove item on error
	void removeItemOnError();	
	//! Start Loading
	void startLoadingButton();
	//! Stop Loading
	void stopLoadingButton();
	//! Take a snapshot
	void takeSnapShot();
	//! Delete the currentItem
	void deleteCurrentItem();
	//! Manage current item information displaying
	void manageItemInformationDisplay(int);
	//! Album Management visibility toggle
	void albumManagementVisibilityToggle();
	//! The album management visibility change
	void albumManagementVisibilityChanged(bool);
	//! Camera property toggle
	void cameraPropertyVisibilityToggle();
	//! The camera property visibility change
	void cameraPropertyVisibilityChanged(bool);
	//! Selection property toggle
	void selectionPropertyVisibilityToggle();
	//! The Selection property visibility change
	void selectionPropertyVisibilityChanged(bool);
	//! Go to Point Rendering mode
	void pointsRenderingMode();
	//! Go to wireframe Rendering mode
	void wireframeRenderingMode();
	//! Go to shading Rendering Mode
	void shadingRenderingMode();
	//! Display about GLC_Player dialog box
	void aboutPlayer();
	//! Go to fullScreen Mode
	void fullScreen();
	//! Refresh the icon in item list
	void refreshIconInItemList();
	//! Display GLC_Player help page
	void help();
	//! Reverse current model normal
	void reverseModelNormal();
	//! Update the view
	void updateView();
	//! Get information about failed loading
	void getErrorInformation();
	//! Display edit light dialog box
	void editLightDialog();
	//! Two sided lightning
	void twoSidedLightning();

//////////////////////////////////////////////////////////////////////
// Private services Functions
//////////////////////////////////////////////////////////////////////
private:
	//! Create RecentFileActionArray
	void createRecentFileActionsArray();
	//! Create RecentFileActionArray
	void createRecentAlbumActionsArray();
	//! Update Recent Files
	void updateRecentsFiles();
	//! Update Recent Albums
	void updateRecentsAlbums();
	//! Open the file
	void openFile(const QString&);
	//! Add current file to recent file
	void addToRecentFiles(const QString&);
	//! Add current Album to recent Albums
	void addToRecentAlbums(const QString&);
	//! drag enter event
	void dragEnterEvent(QDragEnterEvent*);
	//! drop event
	void dropEvent(QDropEvent*);
	//! Load successful
	void loadSuccessful(QString);
	//! Add items
	/*! By default new item are gray*/
	void addItems(QStringList);
	//! Start Loading FileItem
	void startLoading();
	//! Set the current File Item
	void setCurrentFileItem(const QString&);
	//! Update the UI State
	void updateUIState();
	//! Compute the icon of a newly loaded file in back buffer
	void computeIconInBackBuffer(int);
	//! Return icon name with a size
	QString getIconName(bool) const;
	//! Read Application Settings
	void readSettings();
	//! Write Application Settings
	void writeSettings();
	//! Ask for saving the current Session
	bool saveCurrentAlbumDlg();
	//! Apply album saving
	void applySavingAlbum(const QString&);
	//! Open specified album
	void openAlbum(const QString&);

//////////////////////////////////////////////////////////////////////
// private member
//////////////////////////////////////////////////////////////////////
private:
    Ui::glc_playerClass ui;
    OpenglView m_OpenglView;
    //! current file path
    QString m_CurrentPath;
    //! Current Album Path
    QString m_CurrentAlbumPath;
    //! Loading progressBar
    QProgressBar *m_pProgressBar;
    //! Error Message dialog 
	QErrorMessage* m_pQErrorMessage;
	//! Recent File list
	QStringList m_RecentFilesList;
	//! Recent Album list
	QStringList m_RecentAlbumsList;
	//! Maximum number of recent file
	enum {MaxRecentFiles = 10};
	QAction* m_pRecentFileActionsArray[MaxRecentFiles];
	QAction* m_pRecentAlbumActionsArray[MaxRecentFiles];
	//! Current File name
	QString m_CurrentFileName;
	//! Current album name
	QString m_CurrentAlbumName;
	//! The thread wich open file
	OpenFileThread m_OpenFileThread;
	//! File Entry Hash table
	QHash<QString, FileEntry> m_FileEntryHash;
	//! A File Loading is in progress
	bool m_FileLoadingInProgress;
	//! A list Loading is in progress
	bool m_ListLoadingInProgress;
	//! continue List Loading
	bool m_ContinuListLoading;
	//! Number of file not loaded
	int m_NumberOfUnloadedFile;
	//! Number of File with error
	int m_NumberOfErrorFile;
	//! Size of the item list
	QSize m_iconSize;
	//! Make the first loading file current
	bool m_MakeFirstFileCurrent;
	//! Displaying thumbnail in list off files
	bool m_DisplayThumbnails;
	//! Delete selected item
	QAction* m_pActionDeleteSelectedItem;
	//! Get error information
	QAction* m_pActionGetErrorInfo;
	//! Selected instance
	GLC_Instance* m_pCurrentSelection;
	//! display off the info panel
	bool m_dislayInfoPanel;
	//! The selection property widget`
	SelectionProperty* m_pSelectionProperty;
	//! Edit Light dialog box
	EditLightDialog* m_pEditLightDialog;
	//! Activate quit confirmation
	bool m_QuitConfirmation;
    
};

#endif // GLC_PLAYER_H
